<?php
/** Tsonga (Xitsonga)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Thuvack
 */

$messages = array(
# User preference toggles
'tog-justify'              => 'Hikahata xirhapa',
'tog-hideminor'            => 'Tumbeta mindzulamiso leyi tsongo',
'tog-usenewrc'             => 'Kucinca ka sweswinyana loku hlutiweke (JavaScript)',
'tog-showtoc'              => 'Komba nxaxamelo wa leswingandzeni (eka tinhlokomhaka tinharhu kumbe kutlula)',
'tog-rememberpassword'     => 'Tsundzuka ku nghena eka Khompuyuta leyi',
'tog-watchcreations'       => 'Hoxa matluka lawa ndzi matumbuluxaka eka leswi ndziswi languteke',
'tog-watchdefault'         => 'Hoxa matluka lawa ndzi malulamisaka eka leswi ndziswi languteke',
'tog-watchmoves'           => "Hoxa matluka lawa ndzi mayisaka kun'wana eka leswi ndziswi languteke",
'tog-watchdeletion'        => 'Hoxa matluka lawa ndzi masulaka eka leswi ndziswi languteke',
'tog-enotifwatchlistpages' => 'ndzurhumele e-mail loko leswi ndzi swi languteke swi lulamisiwa',
'tog-enotifusertalkpages'  => 'ndzurhumele e-mail loko tluka ra mbulavulo na mina ri lulamisiwa',
'tog-enotifminoredits'     => 'ndzurhumele e-mail loko ku endleka mindzulamiso leyi ntsongo',
'tog-enotifrevealaddr'     => 'Paluxa e-mail yamina eka mapapila lawa ndzimarhumelaka',
'tog-shownumberswatching'  => 'Komba ntsengo wa vatirhisi lava hlaleleke tluka',
'tog-forceeditsummary'     => 'Ndzivutisisi loko ndzinga hoxi nkomiso wa ndzulamiso lowu ndzi wu endleke',
'tog-watchlisthideown'     => 'Tumbeta mindzulamiso ya mina eka leswi ndzi swi languteke',
'tog-watchlisthidebots'    => 'Tumbeta mindzulamiso ya rhobhoti eka leswi ndzi swi languteke',
'tog-watchlisthideminor'   => 'Tumbeta mindzulamiso leyi tsongo eka leswi ndzi swi languteke',
'tog-watchlisthideliu'     => 'Tumbeta mindzulamiso ya vatirhisiwa lava ngheneke eka leswi ndzi swi languteke',
'tog-watchlisthideanons'   => 'Tumbeta mindzulamiso ya vatirhisiwa lavanga tivekiki eka leswi ndzi swi languteke',
'tog-ccmeonemails'         => "Ndzirhumele khopi ya ti e-mail leti ndzi ti rhumelaka van'wana",

'underline-always' => 'Nkarhi hinkwawo',
'underline-never'  => "Swinga endleki ni kan'we",

# Dates
'sunday'    => 'Sonto',
'mon'       => 'Musombhunuko',
'tue'       => 'Ravumbirhi',
'wed'       => 'Ravunharhu',
'thu'       => 'Ravumune',
'fri'       => 'Ravunthlanu',
'sat'       => 'Muqhivela',
'january'   => 'Sunguti',
'february'  => 'Nyenyenyani',
'march'     => 'Nyenyankulu',
'april'     => 'Dzivamusoko',
'may_long'  => 'Mudyaxihi',
'june'      => 'Khotavuxika',
'july'      => 'Mawuwani',
'august'    => 'Mhawuri',
'september' => 'Ndzhati',
'october'   => 'Nhlangula',
'november'  => 'Hukuri',
'december'  => "N'wendzamhala",

'newwindow'      => '(Yi pfula e ndhzawini yintswa)',
'cancel'         => 'Thsika',
'qbfind'         => 'Kuma',
'qbedit'         => 'Lulamisa',
'qbpageoptions'  => 'Tluka leri',
'qbpageinfo'     => 'mongo',
'qbmyoptions'    => 'Matluka ya mina',
'qbspecialpages' => 'Matluka yohlawuleka',
'moredotdotdot'  => "Swin'wana...",
'mypage'         => 'Tluka ramina',
'mytalk'         => 'Mbulavulo namina',
'anontalk'       => 'Vulavula na IP leyi',
'and'            => '&#32;nakambe',

'errorpagetitle'   => 'Xihoxo',
'returnto'         => 'Thlelela e $1.',
'tagline'          => 'Kusuka e {{SITENAME}}',
'help'             => 'Mpfuno',
'search'           => 'Lava',
'searchbutton'     => 'Lava',
'go'               => 'Nghena',
'searcharticle'    => 'Nghena',
'history'          => 'Matimu yaTluka',
'history_short'    => 'Matimu',
'printableversion' => 'Vona Ngangliso',
'edit'             => 'Lulamisa',
'create'           => 'Tumbuluxa',
'editthispage'     => 'Lulamisa Tluka leri',
'create-this-page' => 'Tumbuluxa tluka leri',
'delete'           => 'Sula',
'deletethispage'   => 'Sula tluka leri',
'protect'          => 'Sirhelela',
'newpage'          => 'Tluka rintswa',
'talkpagelinktext' => 'Mbulavulo',
'talk'             => 'Mbulavuriswano',
'toolbox'          => 'Bokisi ra switirhisiwa',
'jumptosearch'     => 'Lava',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'ta {{SITENAME}}',
'aboutpage'            => 'Project:ta',
'currentevents'        => 'Leswi endlekaka sweswi',
'disclaimers'          => 'Swi alanandzu',
'disclaimerpage'       => 'Project:Swithsuxa nadzu hikuangara',
'edithelp'             => 'Mpfuno hi ta mindzulamiso',
'edithelppage'         => 'Help:Mindzulamiso',
'faq'                  => 'FAQ',
'faqpage'              => 'Project:FAQ',
'helppage'             => 'Help:Leswinga ndzeni',
'mainpage'             => 'Tlukankulu',
'mainpage-description' => 'Tluka-Nkulu',
'policy-url'           => 'Project:Policy',
'portal'               => 'Ntsindza wa muganga',
'portal-url'           => 'Project:Community Portal',
'privacy'              => 'Privacy policy',
'privacypage'          => 'Project:Privacy policy',

'badaccess'        => 'Xihoxo hita mpfumelelo',
'badaccess-group0' => 'U hava mpumelelo wo endla xikombelo lexi.',
'badaccess-groups' => 'The action you have requested is limited to users in one of the groups $1.',

'versionrequired'     => 'Version $1 of MediaWiki required',
'versionrequiredtext' => 'Version $1 of MediaWiki is required to use this page.
See [[Special:Version|version page]].',

'ok'                      => 'Hiswona',
'retrievedfrom'           => 'ku suka e "$1"',
'youhavenewmessages'      => 'U na $1 ($2).',
'newmessageslink'         => 'Marungula mantswa',
'newmessagesdifflink'     => 'last change',
'youhavenewmessagesmulti' => 'Una marungula mantswa hi $1',
'editsection'             => 'Lulamisa',
'editold'                 => 'Lulamisa',
'viewsourceold'           => 'Languta vutsari-ntumbuluko',
'editsectionhint'         => 'Lulamisa xiphemu: $1',
'toc'                     => 'Leswinga ndzeni',
'showtoc'                 => 'Kombisa',
'hidetoc'                 => 'Tumbeta',
'thisisdeleted'           => 'Langutisa kumbe Thlerisela $1?',
'viewdeleted'             => 'Langutisa $1?',
'restorelink'             => '{{PLURAL:$1|ndzulamiso lowu suriweke|$1 mindzulamiso leyi suriweke}}',
'feedlinks'               => 'Feed:',
'feed-invalid'            => 'Invalid subscription feed type.',
'feed-unavailable'        => 'Syndication feeds are not available on {{SITENAME}}',
'site-rss-feed'           => '$1 RSS Feed',
'site-atom-feed'          => '$1 Atom Feed',
'page-rss-feed'           => '"$1" RSS Feed',
'page-atom-feed'          => '"$1" Atom Feed',
'red-link-title'          => '$1 (Arisi tsariwa)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Tluka',
'nstab-user'      => 'Tluka ra mutirhisi',
'nstab-media'     => 'Media page',
'nstab-special'   => 'Hlawuleka',
'nstab-project'   => 'Tluka ra Phurojeki',
'nstab-image'     => 'Fayili',
'nstab-mediawiki' => 'Rungula',
'nstab-template'  => 'Template',
'nstab-help'      => 'Tluka ra mpfuno',
'nstab-category'  => 'Xiyenge',

# Main script and global functions
'nosuchaction'      => 'Kuhava xiendlo xo tano',
'nosuchactiontext'  => 'Xikombelo xa URL a xitwisisiwi hi wiki',
'nosuchspecialpage' => 'Ku hava Tluka rero rohlawuleka',
'nospecialpagetext' => '<strong>U kombele tluka ro hlawuleka ro ka ri nga ri kona.</strong>

Vona nxaxamelo wa ma tluka yo hlawuleka e [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error'                => 'Xihoxo',
'databaseerror'        => 'Xihoxo xo Database',
'dberrortext'          => 'A database query syntax error has occurred.
This may indicate a bug in the software.
The last attempted database query was:
<blockquote><tt>$1</tt></blockquote>
from within function "<tt>$2</tt>".
MySQL returned error "<tt>$3: $4</tt>".',
'dberrortextcl'        => 'A database query syntax error has occurred.
The last attempted database query was:
"$1"
from within function "$2".
MySQL returned error "$3: $4"',
'noconnect'            => 'Sorry! The wiki is experiencing some technical difficulties, and cannot contact the database server.<br />
$1',
'nodb'                 => 'Could not select database $1',
'cachederror'          => 'The following is a cached copy of the requested page, and may not be up to date.',
'laggedslavemode'      => 'Warning: Page may not contain recent updates.',
'readonly'             => 'Database locked',
'enterlockreason'      => 'Enter a reason for the lock, including an estimate of when the lock will be released',
'readonlytext'         => 'The database is currently locked to new entries and other modifications, probably for routine database maintenance, after which it will be back to normal.

The administrator who locked it offered this explanation: $1',
'missing-article'      => 'The database did not find the text of a page that it should have found, named "$1" $2.

This is usually caused by following an outdated diff or history link to a page that has been deleted.

If this is not the case, you may have found a bug in the software.
Please report this to an administrator, making note of the URL.',
'missingarticle-rev'   => '(revision#: $1)',
'missingarticle-diff'  => '(Diff: $1, $2)',
'readonly_lag'         => 'The database has been automatically locked while the slave database servers catch up to the master',
'internalerror'        => 'Xihoxo xa le ndzeni',
'internalerror_info'   => 'Internal error: $1',
'filecopyerror'        => 'Could not copy file "$1" to "$2".',
'filerenameerror'      => 'Could not rename file "$1" to "$2".',
'filedeleteerror'      => 'Could not delete file "$1".',
'directorycreateerror' => 'Could not create directory "$1".',
'filenotfound'         => 'Could not find file "$1".',
'fileexistserror'      => 'Unable to write to file "$1": file exists',
'unexpected'           => 'Unexpected value: "$1"="$2".',
'formerror'            => 'Error: could not submit form',
'badarticleerror'      => 'This action cannot be performed on this page.',
'cannotdelete'         => 'Could not delete the page or file specified.
It may have already been deleted by someone else.',
'badtitle'             => 'Bad title',
'badtitletext'         => 'The requested page title was invalid, empty, or an incorrectly linked inter-language or inter-wiki title.
It may contain one or more characters which cannot be used in titles.',
'perfcached'           => 'The following data is cached and may not be up to date.',
'perfcachedts'         => 'The following data is cached, and was last updated $1.',
'querypage-no-updates' => 'Updates for this page are currently disabled.
Data here will not presently be refreshed.',
'wrong_wfQuery_params' => 'Incorrect parameters to wfQuery()<br />
Function: $1<br />
Query: $2',
'viewsource'           => 'Vona tsalwa-tumbuluxa',

# Login and logout pages
'yourpassword'            => 'Vito-mpfungulo:',
'login'                   => 'Pfula u nghena',
'nav-login-createaccount' => 'Pfula unghena / Tumbuluxa akhawunti',
'userlogin'               => 'Pfula unghena / Tumbuluxa akhawunti',
'logout'                  => 'Pfala u famba',
'userlogout'              => 'Pfala u famba',
'nologinlink'             => 'Tumbuluxa akhawunti',
'createaccount'           => 'Tumbuluxa akhawunti',
'yourrealname'            => 'Vito ra ntiyiso:',
'yourlanguage'            => 'Ririmi:',

# Edit pages
'summary'          => 'Nkomiso:',
'minoredit'        => 'Lowu i ndzulamiso wu tsongo',
'watchthis'        => 'Langutisa tluka leri',
'savearticle'      => 'Hlayisa tluka',
'preview'          => 'Ringanisa',
'showpreview'      => 'Komba kuringanisa',
'showdiff'         => 'Komba ku cinca',
'previewnote'      => "'''Lowu i ndzinganiso ntsena;
kucinca a ku sihlayisiwa!'''",
'copyrightwarning' => "Xiya leswaku minyikelo hinkwayo e ka {{SITENAME}} yi tekiwa yitshuxiwe e hansi ka $2 (Vona $1 ku kuma vuxokoxoko).
loko unga tsakeli leswaku vutsari bya wena byi lulamisiwa no aviwa handle ko tweriwa vusiwana, unga tsari laha.<br />
U hi tshembisa nakambe leswaku hi wena mutsari wa leswi nyikeriwaka laha, kumbe leswi u swinyikelaka u swi tekile e xihloveni xa lerivaleni kumbe laha kunga na mpfumelelo wa mani na mani.
'''UNGA RHUMERI MATSALWA LA MA SIRHELERIWEKE HANDLE KA MPFUMELELO!'''",

# History pages
'next'       => 'Leswilandzelaka',
'last'       => 'Swo hetelela',
'page_first' => 'Xo sungula',

# Revision deletion
'rev-delundel' => 'Komba/Tumbeta',
'pagehist'     => 'Matimu ya tluka',
'deletedhist'  => 'Matimu lamasuriweke',

# Search results
'searchhelp-url'        => 'Help:Leswinga ndzeni',
'search-interwiki-more' => '(Leswi engetelekeke)',
'search-relatedarticle' => 'Leswi yelanaka',
'searchrelated'         => 'Yelanaka',
'searchall'             => 'Hinkwaswo',
'showingresults'        => "Kombisa e hansi kufika eka {{PLURAL:$1|'''1''' mbuyelo|'''$1''' mimbuyelo}} Kusungula hi#'''$2'''.",
'powersearch'           => 'Ndzavisiso',

# Preferences page
'mypreferences'   => 'Minhlawulo ya mina',
'prefs-edits'     => 'Ntsengo wa mindzulamiso:',
'skin-preview'    => 'Ndzinganiso',
'datetime'        => 'Siku na nkarhi',
'prefs-watchlist' => 'Nxaxamelo wa Leswivoniwaka',
'saveprefs'       => 'Hlayisa',
'resetprefs'      => 'sula kucinca lokungahlayisiwangiki',
'textboxsize'     => 'Kululamisa',

# Rights
'right-read'       => 'Matluka yo Hlaya',
'right-edit'       => 'Lulamisa ma tluka',
'right-createpage' => 'Tumbuluxa matluka (mangariki eka matluka ya mbulavulo)',
'right-createtalk' => 'Tumbuluxa matluka ya mbulavulo',

# Recent changes
'recentchanges' => 'Ku cinca ka sweswi-nyana',
'hide'          => 'Tumbeta',
'show'          => 'Komba',

# Recent changes linked
'recentchangeslinked' => 'Kuncica loku yelanaka',

# Upload
'upload' => 'Khandziyisa fayili',

# Special:ListFiles
'imgfile'        => 'fayili',
'listfiles'      => 'Nxaxamelo wa tifayili',
'listfiles_date' => 'Siku',
'listfiles_name' => 'vito',

# File description page
'filehist-deleteall' => 'sula hinkwaswo',
'filehist-deleteone' => 'Dlaya',
'filehist-revert'    => 'thlerisela',
'filehist-user'      => 'Mutirhisi',

# Miscellaneous special pages
'newpages'     => 'Matluka mantswa',
'move'         => 'Yi sa kunwana',
'movethispage' => 'Yisa tluka leri ndhzawini yinwana',

# Special:Log
'specialloguserlabel' => 'Mutirhisi:',

# Special:AllPages
'allpages'       => 'Matluka hinkwawo',
'alphaindexline' => '$1 kuya fika eka $2',
'allarticles'    => 'Matluka hinkwawo',

# Special:LinkSearch
'linksearch-ok' => 'Lava',

# Special:Log/newusers
'newuserlog-create-entry' => 'Mutirhisi muntswa',

# E-mail user
'emailuser' => 'rhumela mutirhisi loyi E-mail',

# Watchlist
'watchlist'     => 'Leswi ndziswilanguteke',
'mywatchlist'   => 'Leswi ndziswilanguteke',
'watch'         => 'Languta',
'watchthispage' => 'Languta tluka leri',
'unwatch'       => 'Ungalanguti',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Ulangutile...',
'unwatching' => 'Utshika ku languta...',

# Namespace form on various pages
'invert'         => 'Invert selection',
'blanknamespace' => '(Ntsindza)',

# Contributions
'contributions' => 'Minyikelo ya mutirhisi',
'mycontris'     => 'Minyikelo ya mina',
'contribsub2'   => 'For $1 ($2)',
'nocontribs'    => 'Ku hava ku cinca loku kumiweke eka xiyenge lexi.', # Optional parameter: $1 is the user name
'uctop'         => '(Henhla)',
'month'         => 'Kusukela e ka nhweti ya (kuya endhzaku):',
'year'          => 'Ku sukela e ka lembe ra (kuya endhzaku):',

'sp-contributions-newbies'     => 'Komba minyikela ya ti akhawunti tintswa ntsena',
'sp-contributions-newbies-sub' => 'Eka ti akhawunti ti ntswa',
'sp-contributions-search'      => 'Lava minyikelo',

# What links here
'whatlinkshere' => 'Leswi khwekelaka laha',

# Block/unblock
'contribslink' => 'Minyikelo',

# Tooltip help for the actions
'tooltip-pt-userpage'     => 'Tluka ra vutirhisi',
'tooltip-pt-mytalk'       => 'Mbulavulo namina',
'tooltip-pt-preferences'  => 'Minyikelo ya mina',
'tooltip-pt-mycontris'    => 'Nxaxamelo wa minyikelo ya mina',
'tooltip-pt-logout'       => 'pfala u famba',
'tooltip-ca-protect'      => 'Sirhelela tluka leri',
'tooltip-ca-delete'       => 'Sula tluka leri',
'tooltip-ca-move'         => 'Veka tluka endhzawini yinwana',
'tooltip-n-mainpage'      => 'Endzela tlukankulu',
'tooltip-t-whatlinkshere' => 'Nxaxamelo wa matluka lama khwekelaka laha',
'tooltip-t-upload'        => 'Khandziyisa tifayili',
'tooltip-t-specialpages'  => 'Nxaxamelo wa matluka yo hlawuleka',
'tooltip-ca-nstab-user'   => 'Vona tluka ra mutirhisi',
'tooltip-save'            => 'Hlayiso ku cinca ka wena',
'tooltip-preview'         => 'Ringanisa ku cinca loku uku endleke, Tirhisa Xitirhisiwa lexi ungasi hlayisa tluka leri!',

# Special:SpecialPages
'specialpages' => 'Matluka yo hlawuleka',

);
